==> zio-aws-macie2_2.12-5.17.126.1-sources.jar: zio/aws/macie2/model/AwsService.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class AwsService(invokedBy: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.AwsService = {
    import AwsService.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.AwsService
      .builder()
      .optionallyWith(
        invokedBy.map(value => __string.unwrap(value): java.lang.String)
      )(_.invokedBy)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.AwsService.ReadOnly =
    zio.aws.macie2.model.AwsService.wrap(buildAwsValue())
}
object AwsService {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.macie2.model.AwsService] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.AwsService =
      zio.aws.macie2.model.AwsService(invokedBy.map(value => value))
    def invokedBy: Option[__string]
    def getInvokedBy: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("invokedBy", invokedBy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.AwsService
  ) extends zio.aws.macie2.model.AwsService.ReadOnly {
    override val invokedBy: Option[__string] = scala
      .Option(impl.invokedBy())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.AwsService
  ): zio.aws.macie2.model.AwsService.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.155.1-sources.jar: zio/aws/macie2/model/AwsService.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class AwsService(invokedBy: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.AwsService = {
    import AwsService.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.AwsService
      .builder()
      .optionallyWith(invokedBy.map(value => value: java.lang.String))(
        _.invokedBy
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.AwsService.ReadOnly =
    zio.aws.macie2.model.AwsService.wrap(buildAwsValue())
}
object AwsService {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.macie2.model.AwsService] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.AwsService =
      zio.aws.macie2.model.AwsService(invokedBy.map(value => value))
    def invokedBy: Option[__string]
    def getInvokedBy: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("invokedBy", invokedBy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.AwsService
  ) extends zio.aws.macie2.model.AwsService.ReadOnly {
    override val invokedBy: Option[__string] =
      scala.Option(impl.invokedBy()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.AwsService
  ): zio.aws.macie2.model.AwsService.ReadOnly = new Wrapper(impl)
}
